@@ -9,9 +9,9 @@ use Exporter::Rinci qw(import);
 use IPC::System::Options 'system', 'readpipe', 'run', -log=>1;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-08-30'; # DATE
+our $DATE = '2025-04-17'; # DATE
 our $DIST = 'Clipboard-Any'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $known_clipboard_managers = [qw/klipper parcellite clipit xclip/];
 our $sch_clipboard_manager = ['str', in=>$known_clipboard_managers];
@@ -76,53 +76,82 @@ sub detect_clipboard_manager {
 
     require File::Which;
 
-  KLIPPER:
-    {
-        log_trace "Checking whether clipboard manager klipper is running ...";
-        unless (File::Which::which("qdbus")) {
-            log_trace "qdbus not found in PATH, system is probably not using klipper";
-            last;
-        }
-        my $out;
-        system({capture_merged=>\$out}, "qdbus", "org.kde.klipper", "/klipper");
-        unless ($? == 0) {
-            # note, when klipper is disabled via System Tray Settings > General
-            # > Extra Items, the object path /klipper disappears.
-            log_trace "Failed listing org.kde.klipper /klipper methods, system is probably not using klipper";
-            last;
-        }
-        log_trace "org.kde.klipper/klipper object active, concluding using klipper";
-        return "klipper";
-    }
-
     require Proc::Find;
     no warnings 'once';
     local $Proc::Find::CACHE = 1;
 
+  KLIPPER:
+    {
+        log_trace "Checking whether clipboard manager klipper is running ...";
+
+        METHOD1: {
+              my @paths;
+              if (my $path = File::Which::which("qdbus")) {
+                  log_trace "qdbus found in PATH: $path";
+                  push @paths, $path;
+              } else {
+                  for my $dir ("/usr/lib/qt6/bin", "/usr/lib/qt5/bin") {
+                      if ((-d $dir) && (-x "$dir/qdbus")) {
+                          log_trace "qdbus found in $dir";
+                          push @paths, "$dir/qdbus";
+                      }
+                  }
+              }
+
+              unless (@paths) {
+                  log_trace "qdbus not found (tried PATH, ".join(", ", @paths)."), skipped checking using qdbus";
+                  last;
+              }
+
+              for my $path (@paths) {
+                  my $out;
+                  system({capture_merged=>\$out}, $path, "org.kde.klipper", "/klipper");
+                  unless ($? == 0) {
+                      # note, when klipper is disabled via System Tray Settings >
+                      # General > Extra Items, the object path /klipper disappears.
+                      log_trace "Failed listing org.kde.klipper /klipper methods (using qdus at $path)";
+                      next;
+                  }
+                  log_trace "org.kde.klipper/klipper object active, concluding using klipper";
+                  return "klipper";
+              }
+          }
+
+      METHOD2: {
+            my $pids = Proc::Find::find_proc(name => "dbus-daemon");
+            if (@$pids) {
+                log_trace "There is dbus-daemon running, assuming we are using klipper";
+                return "klipper";
+            } else {
+                log_trace "dbus-daemon process does not seem to be running, probably not using klipper";
+            }
+        }
+    } # KLIPPER
+
   PARCELLITE:
     {
         log_trace "Checking whether clipboard manager parcellite is running ...";
-        my @pids = Proc::Find::find_proc(name => "parcellite");
-        if (@pids) {
+        my $pids = Proc::Find::find_proc(name => "parcellite");
+        if (@$pids) {
             log_trace "parcellite process is running, concluding using parcellite";
             return "parcellite";
         } else {
             log_trace "parcellite process does not seem to be running, probably not using parcellite";
         }
-    }
+    } # PARCELLITE
 
   CLIPIT:
     {
         # basically the same as parcellite
         log_trace "Checking whether clipboard manager clipit is running ...";
-        my @pids = Proc::Find::find_proc(name => "clipit");
-        if (@pids) {
+        my $pids = Proc::Find::find_proc(name => "clipit");
+        if (@$pids) {
             log_trace "clipit process is running, concluding using clipit";
             return "clipit";
         } else {
             log_trace "clipit process does not seem to be running, probably not using clipit";
         }
-    }
+    } # CLIPIT
 
   XCLIP:
     {
@@ -133,7 +162,7 @@ sub detect_clipboard_manager {
         }
         log_trace "xclip found in PATH, concluding using xclip";
         return "xclip";
-    }
+    } # XCLIP
 
     log_trace "No known clipboard manager is detected";
     undef;
@@ -522,7 +551,7 @@ Clipboard::Any - Common interface to clipboard manager functions
 
 =head1 VERSION
 
-This document describes version 0.012 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2024-08-30.
+This document describes version 0.013 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2025-04-17.
 
 =head1 DESCRIPTION
 
@@ -871,7 +900,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024, 2023, 2022 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
